@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import functools
+import os
 from typing import Any, Callable, Dict, Mapping, Optional, Sequence, Type, Union
 
 import pytorch_lightning as pl
@@ -126,7 +127,7 @@ class Task(pl.LightningModule):
 
         Args:
 
-            x: Input to predict. Can be raw data or processed data.
+            x: Input to predict. Can be raw data or processed data. If str, assumed to be a folder of data.
 
             batch_idx: Batch index
 
@@ -142,6 +143,12 @@ class Task(pl.LightningModule):
             The post-processed model predictions
 
         """
+        # enable x to be a path to a folder
+        if isinstance(x, str):
+            files = os.listdir(x)
+            files = [os.path.join(x, y) for y in files]
+            x = files
+
         data_pipeline = data_pipeline or self.data_pipeline
         batch = x if skip_collate_fn else data_pipeline.collate_fn(x)
         batch_x, batch_y = batch if len(batch) == 2 and isinstance(batch, (list, tuple)) else (batch, None)
