@@ -11,12 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Callable, Mapping, Sequence, Type, Union
+from typing import Any, Callable, Mapping, Sequence, Type, Union, Tuple
 
 import torch
-from pytorch_lightning.metrics import Accuracy
 from torch import nn
 from torch.nn import functional as F
+from torch.nn.functional import softmax
+from torchmetrics import Accuracy
 
 from flash.core.classification import ClassificationTask
 from flash.vision.backbones import backbone_and_num_features
@@ -26,21 +27,42 @@ from flash.vision.classification.data import ImageClassificationData, ImageClass
 class ImageClassifier(ClassificationTask):
     """Task that classifies images.
 
+    Use a built in backbone
+
+    Example::
+
+        from flash.vision import ImageClassifier
+
+        classifier = ImageClassifier(backbone='resnet18')
+
+    Or your own backbone (num_features is the number of features produced by your backbone)
+
+    Example::
+
+        from flash.vision import ImageClassifier
+        from torch import nn
+
+        # use any backbone
+        some_backbone = nn.Conv2D(...)
+        num_out_features = 1024
+        classifier = ImageClassifier(backbone=(some_backbone, num_out_features))
+
+
     Args:
         num_classes: Number of classes to classify.
-        backbone: A model to use to compute image features, defaults to ``"resnet18"``.
+        backbone: A string or (model, num_features) tuple to use to compute image features, defaults to ``"resnet18"``.
         pretrained: Use a pretrained backbone, defaults to ``True``.
         loss_fn: Loss function for training, defaults to :func:`torch.nn.functional.cross_entropy`.
         optimizer: Optimizer to use for training, defaults to :class:`torch.optim.SGD`.
         metrics: Metrics to compute for training and evaluation,
-            defaults to :class:`pytorch_lightning.metrics.Accuracy`.
+            defaults to :class:`torchmetrics.Accuracy`.
         learning_rate: Learning rate to use for training, defaults to ``1e-3``.
     """
 
     def __init__(
         self,
         num_classes: int,
-        backbone: str = "resnet18",
+        backbone: Union[str, Tuple[nn.Module, int]] = "resnet18",
         pretrained: bool = True,
         loss_fn: Callable = F.cross_entropy,
         optimizer: Type[torch.optim.Optimizer] = torch.optim.SGD,
@@ -57,7 +79,10 @@ class ImageClassifier(ClassificationTask):
 
         self.save_hyperparameters()
 
-        self.backbone, num_features = backbone_and_num_features(backbone, pretrained)
+        if isinstance(backbone, tuple):
+            self.backbone, num_features = backbone
+        else:
+            self.backbone, num_features = backbone_and_num_features(backbone, pretrained=pretrained)
 
         self.head = nn.Sequential(
             nn.AdaptiveAvgPool2d((1, 1)),
@@ -67,7 +92,7 @@ class ImageClassifier(ClassificationTask):
 
     def forward(self, x) -> Any:
         x = self.backbone(x)
-        return self.head(x)
+        return softmax(self.head(x))
 
     @staticmethod
     def default_pipeline() -> ImageClassificationDataPipeline:
